# Changelog

## 1.0.2 (2025-03-04)

* Add support for more Python versions

## 1.0.1 (2024-01-17)

* Expanding version dependency constraints

## 1.0.0 (2023-11-09)

* First release of AWS MSK IAM SASL Signer Python library.
